# InlineResponse2001

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**records** | [**list[RecordResponseWithComments]**](RecordResponseWithComments.md) | A single record with field and cell values | 
**offset** | **str** | If there are more records, the response will contain an offset. Pass this offset into the next request to fetch the next page of records. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

